# packaging_playground
My own playground on how to create a python package

- https://packaging.python.org/en/latest/tutorials/packaging-projects/

```
py -m pip install --upgrade build
```

```
py -m build
```

RUN ON BASH
```
pylint $(git ls-files '*.py')
```